@@ -1,8 +1,10 @@
 #![cfg(feature = "sled-storage")]
+
+use crate::ExecuteError;
 use {
 	crate::{
-		execute, parse, parse_single, Payload, Query, Result, Row, Storage, StorageInner, Value,
-		WIPError,
+		execute, parse, parse_single, CSVStorage, Payload, Query, Result, Row, SledStorage,
+		Storage, StorageInner, Value, WIPError,
 	},
 	futures::executor::block_on,
 	sqlparser::ast::{
@@ -35,8 +37,8 @@ impl Context {
 ///
 /// There is a number of ways to deposit queries however, depending on the desired output:
 /// - [`Glue::execute()`] -- Might be considered the most generic.
-/// 		Replies with a [Result]<[Payload]>
-/// 		(payload being the response from any type of query).
+///     Replies with a [Result]<[Payload]>
+///     (payload being the response from any type of query).
 /// - [`Glue::execute_many()`] -- Same as `execute()` but will find any number of seperate queries in given text and provide a [Vec] in response.
 /// - [`Glue::select_as_string()`] -- Provides data, only for `SELECT` queries, as [String]s (rather than [Value]s).
 /// - [`Glue::select_as_json()`] -- Provides data, only for `SELECT` queries, as one big [String]; generally useful for webby interactions.
@@ -67,6 +69,42 @@ impl Glue {
 			})
 			.unwrap()
 	}
+	/// Merge existing [Glue] with [Vec] of other [Glue]s
+	/// For example:
+	/// ```
+	/// use multisql::{SledStorage, Storage, Glue};
+	/// let storage = SledStorage::new("data/example_location/example")
+	///   .map(Storage::new_sled)
+	///   .expect("Storage Creation Failed");
+	/// let mut glue = Glue::new(String::from("main"), storage);
+	///
+	/// glue.execute_many("
+	///   DROP TABLE IF EXISTS test;
+	///   CREATE TABLE test (id INTEGER);
+	///   INSERT INTO test VALUES (1),(2);
+	///   SELECT * FROM test WHERE id > 1;
+	/// ");
+	///
+	/// let other_storage = SledStorage::new("data/example_location/example_other")
+	///   .map(Storage::new_sled)
+	///   .expect("Storage Creation Failed");
+	/// let mut other_glue = Glue::new(String::from("other"), other_storage);
+	///
+	/// glue.extend(vec![other_glue]);
+	/// ```
+	///
+	pub fn extend(&mut self, glues: Vec<Glue>) {
+		self.storages.extend(
+			glues
+				.into_iter()
+				.reduce(|mut main, other| {
+					main.storages.extend(other.storages);
+					main
+				})
+				.unwrap()
+				.storages,
+		)
+	}
 }
 
 /// Internal: Modify
@@ -104,6 +142,38 @@ impl Glue {
 	}
 	/// Will execute a pre-parsed query (see [Glue::pre_parse()] for more).
 	pub fn execute_parsed(&mut self, query: Query) -> Result<Payload> {
+		if let Query(Statement::CreateDatabase {
+			db_name,
+			if_not_exists,
+			location,
+			..
+		}) = query
+		{
+			let store_name = db_name.0[0].value.clone();
+			return if self.storages.iter().any(|(store, _)| store == &store_name) {
+				if if_not_exists {
+					Ok(Payload::Success)
+				} else {
+					Err(ExecuteError::DatabaseExists(store_name).into())
+				}
+			} else {
+				match location {
+					None => Err(ExecuteError::InvalidDatabaseLocation.into()), // TODO: Memory
+					Some(location) => {
+						let store = if location.ends_with("/") {
+							Storage::new_sled(SledStorage::new(&location)?)
+						} else if location.ends_with(".csv") {
+							Storage::new_csv(CSVStorage::new(&location)?)
+						} else {
+							return Err(ExecuteError::InvalidDatabaseLocation.into());
+						};
+						self.extend(vec![Glue::new(store_name, store)]);
+						Ok(Payload::Success)
+					}
+				}
+			};
+		}
+
 		let mut storages: Vec<(String, Box<StorageInner>)> = self
 			.storages
 			.iter_mut()
